pub struct AllOutputsAllFieldsTable<Kind: AllFieldsTableKind>(/* private fields */);Expand description
A wrapper holding the table sets for all requested outputs. (Wrapping since we want to have the same fields and mapping methods. A type alias would currently lose the trait restriction checks in Rust’s type system.)
Implementations
Sourceimpl AllOutputsAllFieldsTable<SingleRunStats>
impl AllOutputsAllFieldsTable<SingleRunStats>
pub fn from_log_data_tree( log_data_tree: &LogDataTree<'_>, evaluation_opts: &EvaluationOpts, output_opts: OutputVariants<PathBuf>, is_final_file: bool, ) -> Result<Self>
Sourceimpl AllOutputsAllFieldsTable<SummaryStats>
impl AllOutputsAllFieldsTable<SummaryStats>
pub fn summary_stats( aoafts: &[AllOutputsAllFieldsTable<SingleRunStats>], field_selector: StatsField<TILE_COUNT>, evaluation_opts: &EvaluationOpts, output_opts: OutputVariants<PathBuf>, is_final_file: bool, ) -> AllOutputsAllFieldsTable<SummaryStats>
Sourceimpl<Kind: AllFieldsTableKind> AllOutputsAllFieldsTable<Kind>
impl<Kind: AllFieldsTableKind> AllOutputsAllFieldsTable<Kind>
Sourcepub fn write_to_files(self, flame_field: StatsField<TILE_COUNT>) -> Result<()>
pub fn write_to_files(self, flame_field: StatsField<TILE_COUNT>) -> Result<()>
Write to all output files originally specified; gives an error
unless the is_final_file for this instance was true. (Taking
ownership only because try_map currently requires so.)
Methods from Deref<Target = OutputVariants<AllFieldsTableWithOutputPathOrBase<Kind>>>
Sourcepub fn get(&self, case: CheckedOutputOptionsMapCase) -> &Option<T>
pub fn get(&self, case: CheckedOutputOptionsMapCase) -> &Option<T>
get a field